summaryrefslogtreecommitdiffstats
path: root/ksirc/puke/controller.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'ksirc/puke/controller.cpp')
-rw-r--r--ksirc/puke/controller.cpp50
1 files changed, 25 insertions, 25 deletions
diff --git a/ksirc/puke/controller.cpp b/ksirc/puke/controller.cpp
index 04017529..faa5cf23 100644
--- a/ksirc/puke/controller.cpp
+++ b/ksirc/puke/controller.cpp
@@ -15,7 +15,7 @@
#include <sys/stat.h>
using namespace std; // iostream.h include cstring which puts strlen into
- // std:: namespace, which breaks Qt's strlen() call
+ // std:: namespace, which breaks TQt's strlen() call
// in tqcstring.h (in gcc3's libstdc++)
#include <klibloader.h>
@@ -32,7 +32,7 @@ using namespace std; // iostream.h include cstring which puts strlen into
#include "pframe.h"
#include "pkfiledialog.h"
#include "plabel.h"
-#include "playout.h"
+#include "ptqlayout.h"
#include "plined.h"
#include "plistbox.h"
#include "pmenudta.h"
@@ -50,7 +50,7 @@ using namespace std; // iostream.h include cstring which puts strlen into
uint PukeController::uiBaseWinId = 10; // Gives a little seperation from the controller id
-PukeController::PukeController(TQString sock, TQObject *parent, const char *name) : PObject( parent, name )
+PukeController::PukeController(TQString sock, TQObject *tqparent, const char *name) : PObject( tqparent, name )
{
int len, prev_umask;
struct sockaddr_un unix_addr;
@@ -173,7 +173,7 @@ void PukeController::NewConnect(int)
fcntl(cfd, F_SETFL, O_NONBLOCK); // Set it non-block so that
// cfd() never blocks.
- fdStatus *fds = new fdStatus();
+ fdtqStatus *fds = new fdtqStatus();
fds->sr = new TQSocketNotifier(cfd, TQSocketNotifier::Read, this);
fds->sw = new TQSocketNotifier(cfd, TQSocketNotifier::Write, this);
connect(fds->sr, TQT_SIGNAL(activated(int)),
@@ -562,7 +562,7 @@ void PukeController::hdlrPukeFetchWidget(int fd, PukeMessage *pm)
widgetId wIret;
/*
* The parent widget ID and type are packed into the iArg
* the pattern is 2 shorts.
*/
@@ -580,17 +580,17 @@ void PukeController::hdlrPukeFetchWidget(int fd, PukeMessage *pm)
wIret.iWinId = uiBaseWinId;
wIret.fd = fd;
// CreateArgs arg = CreateArgs(this, pm, &wIret, parent)
CreateArgs arg(this, pm, &wIret, 0);
// Let's go looking for the widget
// Match any class with the right name
TQObject *obj = 0x0;
- if(parent() && (strcmp(name, parent()->name()) == 0)){
- obj = parent();
+ if(tqparent() && (strcmp(name, tqparent()->name()) == 0)){
+ obj = tqparent();
}
else {
- obj = objFinder::find(name, 0x0);
+ obj = objFinder::tqfind(name, 0x0);
if(obj == 0){
wIret.fd = 0;
wIret.iWinId = 0;
@@ -642,10 +642,10 @@ void PukeController::hdlrPukeDeleteWidget(int fd, PukeMessage *pm)
kdDebug(5008) << "WidgetRunner:: no such set of widget descriptors?" << endl;
throw(errorCommandFailed(PUKE_INVALID, INVALID_DEL_NO_SUCH_CONNECTION));
}
- if(qidWS->find(wI.iWinId)){
+ if(qidWS->tqfind(wI.iWinId)){
// Remove the list item then delete the widget. This will stop
// the destroyed signal from trying to remove it again.
- PObject *pw = qidWS->find(wI.iWinId)->pwidget;
+ PObject *pw = qidWS->tqfind(wI.iWinId)->pwidget;
qidWS->remove(wI.iWinId);
delete pw; pw = 0;
pmRet.iCommand = PUKE_WIDGET_DELETE_ACK;
@@ -661,8 +661,8 @@ void PukeController::hdlrPukeDeleteWidget(int fd, PukeMessage *pm)
throw(errorCommandFailed(PUKE_INVALID, INVALID_DEL_NO_SUCH_WIDGET));
}
- WidgetList[fd]->find(wI.iWinId)->pwidget->manTerm();
- delete WidgetList[fd]->find(wI.iWinId)->pwidget;
+ WidgetList[fd]->tqfind(wI.iWinId)->pwidget->manTerm();
+ delete WidgetList[fd]->tqfind(wI.iWinId)->pwidget;
PukeMessage pmRet = *pm;
pmRet.iCommand = PUKE_WIDGET_DELETE_ACK;
@@ -711,7 +711,7 @@ void PukeController::closefd(int fd)
PObject *po = 0x0;
while(it.current()){
/*
- * Delete all the layouts first
+ * Delete all the tqlayouts first
*
*/
if(it.current()->type == POBJECT_LAYOUT){
@@ -745,7 +745,7 @@ void PukeController::closefd(int fd)
bool PukeController::checkWidgetId(widgetId *pwi)
{
if(WidgetList[pwi->fd] != NULL)
- if(WidgetList[pwi->fd]->find(pwi->iWinId) != NULL)
+ if(WidgetList[pwi->fd]->tqfind(pwi->iWinId) != NULL)
return TRUE;
return FALSE;
@@ -753,7 +753,7 @@ bool PukeController::checkWidgetId(widgetId *pwi)
PObject *PukeController::id2pobject(widgetId *pwi){
if(checkWidgetId(pwi) == TRUE){
- return WidgetList[pwi->fd]->find(pwi->iWinId)->pwidget;
+ return WidgetList[pwi->fd]->tqfind(pwi->iWinId)->pwidget;
}
throw(errorNoSuchWidget(*pwi));
return 0; // never reached
@@ -868,7 +868,7 @@ void PukeController::messageHandler(int fd, PukeMessage *pm) {
return;
}
- TQString libName = "ksirc/lib"+TQString::fromLatin1(pm->cArg);
+ TQString libName = "ksirc/lib"+TQString::tqfromLatin1(pm->cArg);
if (libName.right(3) == ".so")
libName = libName.left(libName.length()-2)+"la";
@@ -899,7 +899,7 @@ void PukeController::messageHandler(int fd, PukeMessage *pm) {
}
else{
if(checkWidgetId(&wI) == TRUE){
- WidgetList[wI.fd]->find(wI.iWinId)->pwidget->messageHandler(fd, pm);
+ WidgetList[wI.fd]->tqfind(wI.iWinId)->pwidget->messageHandler(fd, pm);
}
else{
PukeMessage pmRet;
@@ -915,11 +915,11 @@ void PukeController::messageHandler(int fd, PukeMessage *pm) {
widgetId PukeController::createWidget(widgetId wI, PukeMessage *pm)
{
widgetId wIret;
- PWidget *parent = 0; // Defaults to no parent
+ PWidget *tqparent = 0; // Defaults to no tqparent
WidgetS *ws = new WidgetS;
/*
* The parent widget ID and type are packed into the iArg
* the pattern is 2 shorts.
*/
@@ -928,7 +928,7 @@ widgetId PukeController::createWidget(widgetId wI, PukeMessage *pm)
if(found != 2)
throw(errorCommandFailed(PUKE_INVALID,7));
- wI.iWinId = iParent; // wI is the identifier for the parent widget
+ wI.iWinId = iParent; // wI is the identifier for the tqparent widget
if(widgetCF[iType] == NULL){ // No such widget, bail out.
wIret.fd = 0;
@@ -943,15 +943,15 @@ widgetId PukeController::createWidget(widgetId wI, PukeMessage *pm)
wIret.fd = wI.fd;
if(checkWidgetId(&wI) == TRUE){
- PObject *obj = WidgetList[wI.fd]->find(wI.iWinId)->pwidget;
+ PObject *obj = WidgetList[wI.fd]->tqfind(wI.iWinId)->pwidget;
if(obj->widget()->isWidgetType() == FALSE){
throw(errorCommandFailed(PUKE_INVALID, 0));
}
- parent = (PWidget *) obj;
+ tqparent = (PWidget *) obj;
}
- // CreateArgs arg = CreateArgs(this, pm, &wIret, parent)
- CreateArgs arg(this, pm, &wIret, parent);
+ // CreateArgs arg = CreateArgs(this, pm, &wIret, tqparent)
+ CreateArgs arg(this, pm, &wIret, tqparent);
ws->pwidget = (widgetCF[iType]->wc)(arg);
if (ws->pwidget->hasError())
{
@@ -562,7 +562,7 @@ void PukeController::hdlrPukeFetchWidget(int fd, PukeMessage *pm)
widgetId wIret;
/*
- * The parent widget ID and type are packed into the iArg
+ * The tqparent widget ID and type are packed into the iArg
* the pattern is 2 shorts.
*/
@@ -580,17 +580,17 @@ void PukeController::hdlrPukeFetchWidget(int fd, PukeMessage *pm)
wIret.iWinId = uiBaseWinId;
wIret.fd = fd;
- // CreateArgs arg = CreateArgs(this, pm, &wIret, parent)
+ // CreateArgs arg = CreateArgs(this, pm, &wIret, tqparent)
CreateArgs arg(this, pm, &wIret, 0);
// Let's go looking for the widget
@@ -915,11 +915,11 @@ void PukeController::messageHandler(int fd, PukeMessage *pm) {
WidgetS *ws = new WidgetS;
/*
- * The parent widget ID and type are packed into the iArg
+ * The tqparent widget ID and type are packed into the iArg
* the pattern is 2 shorts.
*/